@@ -8,7 +8,7 @@ mut_mat <- readRDS(system.file("states/mut_mat_data.rds",
   package = "MutationalPatterns"
 ))
 
-contexts <- rownames(mut_mat)
+contexts <- rownames(mut_mat)[1:6]
 
 # Get context mismatches
 context_mismatches <- readRDS(system.file("states/context_mismatches.rds",
@@ -23,5 +23,5 @@ test_that("Output has correct class", {
 })
 
 test_that("Output has correct size", {
-  expect_equal(dim(output), c(216, 7))
+  expect_equal(dim(output), c(240, 7))
 })
